@@ -58,8 +58,6 @@ function initLevel() {
     items.progressbar.value = 1
     items.progressbar.value = 0
     items.descriptionPanel.visible = false
-    // Stop audio if necessary (switch from level 2 at beginning to a new level for example)
-    items.audioVoices.stop()
     items.instruction.visible = true
 
     reload();
@@ -76,6 +74,10 @@ function nextLevel() {
         items.score.currentSubLevel = 1
     }
     initLevel();
+
+    // Stop audio if necessary (switch from level 2 at beginning to a new level for example)
+    items.audioVoices.stop()
+
     if (items.score.currentSubLevel == 2) {
         items.progressbar.value = 0;
         initSubSubLevel();
@@ -95,8 +97,11 @@ function previousLevel() {
     }
     initLevel();
 
+    // Stop audio if necessary (switch from level 2 at beginning to a new level for example)
+    items.audioVoices.stop()
+
     if(items.score.currentSubLevel == 2 && items.hasAudioQuestions) {
-        items.audioVoices.play(getCurrentQuestion().audio);
+       repeat();
     }
 }
 
@@ -108,17 +113,18 @@ function isComplete() {
     return true;
 }
 
-function initSubSubLevel() {
+function initSubSubLevel(IsNext) {
     if(items.progressbar.value == items.dataModel.count) {
         items.bonus.good("smiley");
     }
-     if(items.score.currentSubLevel == 2 && items.hasAudioQuestions) {
-        items.audioVoices.play(getCurrentQuestion().audio);
+     if(items.score.currentSubLevel == 2 && items.hasAudioQuestions && getCurrentQuestion()) {
+         repeat();
     }
 }
 
 function nextSubSubLevel() {
-    initSubSubLevel()
+    items.audioVoices.silence(2000)
+    initSubSubLevel(true)
 }
 
 function reload() {
@@ -128,7 +134,9 @@ function reload() {
 }
 
 function repeat() {
-    items.audioVoices.play(getCurrentQuestion().audio);
+    items.audioVoices.stop()
+    items.audioVoices.clearQueue()
+    items.audioVoices.append(getCurrentQuestion().audio);
 }
 
 function getCurrentQuestion() {
