@@ -36,7 +36,7 @@ function getMinusTable(table) {
     var result = []
     for(var i = 1; i <= 10; ++i) {
         // The mathematical subtraction sign
-        result.push(["" + (i + table) + " " + qsTr("-") + " " + table,
+        result.push(["" + (i + table) + " " + qsTr("−") + " " + table,
                       i])
     }
     return result
