@@ -21,6 +21,7 @@
  */
 .pragma library
 .import "qrc:/gcompris/src/core/core.js" as Core
+.import GCompris 1.0 as GCompris
 
 var url = "qrc:/gcompris/src/activities/money/resource/"
 
@@ -643,7 +644,11 @@ function initLevel() {
             price += cents
         }
 
-        var priceText = Number(price).toLocaleCurrencyString(Qt.locale())
+        var locale = GCompris.ApplicationSettings.locale
+        if(locale == "system") {
+            locale = Qt.locale().name == "C" ? "en_US" : Qt.locale().name
+        }
+        var priceText = Number(price).toLocaleCurrencyString(Qt.locale(locale))
         if(!centsMode) {
             // Strip floating part
             priceText = priceText.replace((/.00/), "")
@@ -690,7 +695,11 @@ function initLevel() {
         for(var i=0; i < tuxMoney.length; i++)
             tuxTotal += tuxMoney[i].val
 
-        var priceText = Number(tuxTotal).toLocaleCurrencyString(Qt.locale())
+        var locale = GCompris.ApplicationSettings.locale
+        if(locale == "system") {
+            locale = Qt.locale().name == "C" ? "en_US" : Qt.locale().name
+        }
+        var priceText = Number(tuxTotal).toLocaleCurrencyString(Qt.locale(locale))
         if(!centsMode) {
             // Strip floating part
             priceText = priceText.replace((/.00/), "")
